from minilsap import linear_sum_assignment as solve


def test_solve_square():
    mat = [[82, 83, 69, 92], [77, 37, 49, 92], [11, 69, 5, 86], [8, 9, 98, 23]]
    rows, cols = solve(mat)
    assert rows.tolist() == [0, 1, 2, 3]
    assert cols.tolist() == [2, 1, 0, 3]


def test_solve_non_square():
    mat = [[82, 83, 69, 92], [77, 37, 49, 92], [11, 69, 5, 86]]
    rows, cols = solve(mat)
    assert rows.tolist() == [0, 1, 2]
    assert cols.tolist() == [2, 1, 0]


def test_solve_empty():
    rows, cols = solve([])
    assert rows.tolist() == []
    assert cols.tolist() == []

    rows, cols = solve([[]])
    assert rows.tolist() == []
    assert cols.tolist() == []



from __future__ import annotations

from typing import Sequence, Union, Tuple, TYPE_CHECKING

if TYPE_CHECKING:
    from numpy import ndarray
    from numpy.typing import ArrayLike


def linear_sum_assignment(
    cost_matrix: Union[Sequence[Sequence[float]], ArrayLike],
    maximize: bool = False,
) -> Tuple[ndarray, ndarray]:
    """Solve the linear sum assignment problem.

    This function is a drop-in replacement for
    ``scipy.optimize.linear_sum_assignment()``.

    Parameters:
        cost_matrix: the cost matrix
        maximize: whether the total weight should be maximized (``True``) or
            minimized (``False``)

    Returns:
        an array of row indices and an array of column indices giving the optimal
        assignment. The cost of the assignment can be computed as
        ``cost_matrix[row_ind, col_ind].sum()``.
    """
    from numpy import asarray, float64
    from ._lsap import solve

    cost_matrix = asarray(cost_matrix, dtype=float64, order="C")
    return solve(cost_matrix, maximize)
